package
Version:
v0.1.0-alpha.2
Opens a new window with list of versions in this module.
Published: Nov 25, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Config contains full Simple Sidecar configuration
New returns a new Config struct
type ParametersConfig struct {
Port string
WriteTimeout int
ReadTimeout int
IdleTimeout int
GracefulTimeout int
}
ParametersConfig contains the API server configuration
Source Files
¶
Click to show internal directories.
Click to hide internal directories.